"""
Brawl Stars API Wrapper
~~~~~~~~~~~~~~~~~~~~~~~~~
A basic wrapper for the Brawl Stars API.
:copyright: (c) 2022-Present PyStarr
:license: MIT, see LICENSE for more details.
"""

from .API import API
from .main import Client
from .objects import *

__title__ = 'brawlpy'
__author__ = 'PyStarr'
__license__ = 'MIT'
__copyright__ = 'Copyright 2022-Present PyStarr'
__version__ = '1.2.0'