brawlers = {
    "16000000" : "https://drive.google.com/uc?export=view&id=1dAvFR908593LzntFYVsJXr_um4qiFRwz",
    "16000001" : "https://drive.google.com/uc?export=view&id=1xHmMCxksAd3KWuifEpGKMVzLugYhmFvD",
    "16000002" : "https://drive.google.com/uc?export=view&id=1SOMlveroyDJEXULdJ8_WkEKWtDp74kxa",
    "16000003" : "https://drive.google.com/uc?export=view&id=10e3izEMpLRq5S_1g9REZZYFv6a_Lszg3",
    "16000004" : "https://drive.google.com/uc?export=view&id=1WqsVnqCp5BhMSaXEAdVJMFhodl4x1c6S",
    "16000005" : "https://drive.google.com/uc?export=view&id=1aW9_LnZYGbfIIAEMeRD-OUBUJ2o8zdCy",
    "16000006" : "https://drive.google.com/uc?export=view&id=14Ln4niaVoZQS5U-kxHbjb_M3FeJQ4fcv",
    "16000007" : "https://drive.google.com/uc?export=view&id=1i_XawzubrMsTwibnCleEGgILkZWJLPeJ",
    "16000008" : "https://drive.google.com/uc?export=view&id=1rob9jd_cMT1Dj_qt7RRjWegwGQca1AKX",
    "16000009" : "https://drive.google.com/uc?export=view&id=18ygqoJ2FKeKY5EqmhcBRTG5UQxry2qN_",
    "16000010" : "https://drive.google.com/uc?export=view&id=17xoy5Aw4dpJJID97eKbcX_IcaG6OA9I7",
    "16000011" : "https://drive.google.com/uc?export=view&id=1H0MZlrGvntFduEcqaSHm0TYgx5DE-Wlc",
    "16000012" : "https://drive.google.com/uc?export=view&id=16tLAAVvb_KwhrEOqPRsFTG01D_E8lKye",
    "16000013" : "https://drive.google.com/uc?export=view&id=1aQlEFbymNtxn0nkDP2GoZFDiKsMR9D4f",
    "16000014" : "https://drive.google.com/uc?export=view&id=1Fkct5iCvdjMWi-g3KwdCck1_OXs3sHlC",
    "16000015" : "https://drive.google.com/uc?export=view&id=15HiIxoF9194HOIFuxqUTQ-h5-YQSEoVG",
    "16000016" : "https://drive.google.com/uc?export=view&id=1GeRdbB_T6QH4q77V5DZq_vkXnvfkZpYk",
    "16000017" : "https://drive.google.com/uc?export=view&id=1LjGfus6pXt9A2hYEeOfBIcrcTSgiAN1_",
    "16000018" : "https://drive.google.com/uc?export=view&id=1UTB7mep0PrUT9p1MsgW25YhNjda5gsg0",
    "16000019" : "https://drive.google.com/uc?export=view&id=1EWAOzE0kNc3cw3DH7RfM-_6Jz-D9ALoo",
    "16000020" : "https://drive.google.com/uc?export=view&id=1nQVBdJb6PkdwaV566CGM21uA7ttJDhvY",
    "16000021" : "https://drive.google.com/uc?export=view&id=1mbICcY_h1YdUxvoSZIToS14JUaZvbE2l",
    "16000022" : "https://drive.google.com/uc?export=view&id=1udUF9M8ino0A3ZIGw8ptSaZC0lh9LTWs",
    "16000023" : "https://drive.google.com/uc?export=view&id=1Q2-FHGHUoNfmovn1ZObRjr_i6KJh610Q",
    "16000024" : "https://drive.google.com/uc?export=view&id=1qfWtCalsrYzQckKFOIBvNY7nDKO8IuM9",
    "16000025" : "https://drive.google.com/uc?export=view&id=1YNQMCne024WiNwklnhGsYXizuli7uoMl",
    "16000026" : "https://drive.google.com/uc?export=view&id=1X0Fp62TTlIQ6PX8gipq0XuN9MCAdFlpa",
    "16000027" : "https://drive.google.com/uc?export=view&id=1xLRF0bCblZkukyfM2h0p_N6NcPNOY77a",
    "16000028" : "https://drive.google.com/uc?export=view&id=1Hzk5vLYHSb0TVGf0LjrX0G2TRyQqaIvc",
    "16000029" : "https://drive.google.com/uc?export=view&id=14X3DhdU2XzzFU3sxOK2mIyfuqeuGIdO5",
    "16000030" : "https://drive.google.com/uc?export=view&id=1qv2PjG2e-AU2Qhe0IGm7M7F0-urKN998",
    "16000031" : "https://drive.google.com/uc?export=view&id=1U3neaBogNuy9oGY9EJqJ6wWnG_h4NRLk",
    "16000032" : "https://drive.google.com/uc?export=view&id=1XjQA6HwUkQuJMLNKyT2Drcu8xtpKYz6m",
    "16000034" : "https://drive.google.com/uc?export=view&id=1xsmR6sM71s7wwZThypyESVjvjBrN4c50",
    "16000035" : "https://drive.google.com/uc?export=view&id=15NspTtmz6xrfr7lY-ewl7-686s64Xpaf",
    "16000036" : "https://drive.google.com/uc?export=view&id=1xLvjeONLrU-wOUhxvv_FHZAqFCf03gtk",
    "16000037" : "https://drive.google.com/uc?export=view&id=1rVLeFZpVz5Mi2-1d6smUHXVSvvWJzjFU",
    "16000038" : "https://drive.google.com/uc?export=view&id=16jHS2sqJlDjy0byy4Rr3LZsWQJdfMHqJ",
    "16000039" : "https://drive.google.com/uc?export=view&id=1K7Ah2vU0BbEn1AlYeMaynqUXdHxWNfgC",
    "16000040" : "https://drive.google.com/uc?export=view&id=1V9rczuRWlZWcM-lTkNmQiPlGoAo-TkZK",
    "16000041" : "https://drive.google.com/uc?export=view&id=1PRKXASBnSw1Z6Dg9UcVn9JhLq1guZQf6",
    "16000042" : "https://drive.google.com/uc?export=view&id=1WP3X8pH_THrfXarX1gWUxyivV2h3uz3v",
    "16000043" : "https://drive.google.com/uc?export=view&id=1-AA3rab9yKtXvtiU1HW3S-vwLNjPZofO",
    "16000044" : "https://drive.google.com/uc?export=view&id=1ovyRjUNZGczg2KNIdvf-CkSjnMLdcgpL",
    "16000045" : "https://drive.google.com/uc?export=view&id=12VBQqRTEDydB6DvUHTt6EZQAoci2pGe6",
    "16000046" : "https://drive.google.com/uc?export=view&id=1idOjVsdgILT4ZFZ1Of7veixGNQYLcoEJ",
    "16000047" : "https://drive.google.com/uc?export=view&id=1O6wdsVcUsB8-sLcfodAV5xRmwVaVo9eD",
    "16000048" : "https://drive.google.com/uc?export=view&id=14Y-4BYVo2l2sn_3NEji_48FOCLNbeOKk",
    "16000049" : "https://drive.google.com/uc?export=view&id=1EBqNyrgq2-RPVYIHXTgWjOfCevsCzGfA",
    "16000050" : "https://drive.google.com/uc?export=view&id=1AQ32wTsnKM564EnGa1wEZ6n7dNnQ_L0A",
    "16000051" : "https://drive.google.com/uc?export=view&id=1XbbWDTLTs5Ms3ogqLpKyOqfEwg6k7ED0",
    "16000052" : "https://drive.google.com/uc?export=view&id=18dg1sJLDZc-pTBaKj4HTsSDkxypHfqNQ",
    "16000053" : "https://drive.google.com/uc?export=view&id=1lQ_mZd65ctx6YuhstrUBclptIvoAS6yl",
    "16000054" : "https://drive.google.com/uc?export=view&id=1Ujkutn8ovAs_9uEu9F590jhwNGCZRK-_"
}
